Plover Michela
==============

Michela (Italian system) support for Plover.


Documentation
-------------

Details about the theory and the main dictionary contents can be found
`here <https://sillabix.gitbooks.io/dizionario-test/>`_ (in Italian).


Release history
---------------

0.1.4
~~~~~

* update main dictionary and split it into three parts: main, numbers, and commands

0.1.3
~~~~~

* fix undo stroke (use ``U``, not ``X``)

0.1.2
~~~~~

* add dictionaries
